//
//  Networking.swift
//  MVVM
//
//  Created by Ivan Chavdarov Ivanov on 27.07.23.
//

import Foundation

// MARK: - Custom error
enum NetworkError: Error {
    case urlNotValid
    case noData
    case parsingError
}

class Networking {
    // MARK: - API call
    func getData(completion: @escaping (_ result: Result<[TodoElement], NetworkError>) -> Void) {
        print("Calling endpoint...")
        
        let url = URL(string: "https://jsonplaceholder.typicode.com/todos")!
        let task = URLSession.shared.dataTask(with: url) { data, response, error in
            if let error = error {
                print("Error occurred:", error)
                completion(.failure(.urlNotValid))
                return
            }
            
            guard let responseData = data else {
                print("No data received from the server.")
                completion(.failure(.noData))
                return
            }
            
            do {
                let jsonData = try JSONDecoder().decode([TodoElement].self, from: responseData)
                completion(.success(jsonData))
                print("Ready")
            } catch {
                print("Error in parsing JSON file:", error)
                completion(.failure(.parsingError))
            }
        }
        task.resume()
    }
}
